@@ -16,9 +16,8 @@
 #' @export
 compare <- function(x, metric = 2000, diag = FALSE, upper = FALSE) {
   # Validation
-  check_package("spacesXYZ")
-  if (!is.atomic(x) || !is.character(x))
-    stop("x must be a character vector of colors.", call. = FALSE)
+  assert_package("spacesXYZ")
+  assert_color(x)
 
   # Hex to RGB
   RGB <- t(grDevices::col2rgb(x, alpha = FALSE))
